@@ -6,15 +6,16 @@
 # @create date 2019-11-11
 # @desc [one command to unpack archives]
 
+import os
 import sys
 
 import click
 
-from python_extrac.utils import check_is_file, decompression, del_file, call_shell
+from python_extrac.utils import check_is_file, decompression, call_shell
 
 CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
 
-help_string = """this is a magic command line tool to unpack archives, 
+help_string = """this is a magic command line tool to unpack archives,
                 only use one command "x FILE", enjoy it"""
 
 
@@ -44,7 +45,7 @@ def cli(file_path, remove):
         check_is_file(file_path)
         decompression(full_path)
     if remove:
-        del_file(file_path)
+        os.remove(file_path)
 
 
 if __name__ == "__main__":
